clear all
clc
close all

global hrs disimm rel_rho R0 lambda rel_lambda
global Pop ini_inf T_years  T  d_vaccine  rel_prod_Q
global sigma gamma tau psi d_conv V_false_neg S_false_neg
global rU_start 

%__________________________________________________________________________
%Policy parameters - Fixed
rU_start                = 0.00275;    %*******

reopen_date             = datetime(2020,6,1);
days_Mar20_to_reopen    = days(reopen_date-datetime(2020,3,20));

testing_date            = datetime(2020,6,1);
days_Mar20_to_testing   = days(testing_date-datetime(2020,3,20));

vaccine_date            = datetime(2021,3,20);
days_Mar20_to_vaccine   = days(vaccine_date-datetime(2020,3,20));

xiU_c                   = 0.0026;       % constant Q rate for U  (hourly)
rU_exp                  = 0 ;           % additional reopening rate

% tests have no false negatives for baseline
V_false_neg             = 0;
S_false_neg             = 0; 
%__________________________________________________________________________
% Quarantine technology
rel_lambda              = 0.16 ;        % lambdaQ/lambda
%__________________________________________________________________________
% Time step
hrs                     = 14;           % Periods per day       
%__________________________________________________________________________
% Parameters
rel_prod_Q              = 0.9;                  % Relative productivity of quarantined (A_rel in paper)
disimm                  = 0;                    % Dis-Immunity  (0 = complete immunity, 1 = no immunity) 	
rel_rho                 = 1;                    % rhoA/rhoS  Relative infectiousness rate

psi                     = 0.6;                  % Fraction who develop symptoms (TA)

sigma                   = hrs*6;                % for transition matrix
gamma                   = hrs*8;                % for transition matrix

R0                      = 2.6;                  % Basic reproduction number
lambda                  = 1;                    % Meeting rate (normalized to 1)
Pop                     = 340000000;            % Population
T_years                 = 5;                    
T                       = T_years*365*hrs;      
ini_inf                 = 1*340000;             % 0.1% infected
%__________________________________________________________________________
% Bisection stuff
% d_conv is the date when we define 'long term' for target deaths
d_conv       = 1000;

death_inflator          = 1.33;  % Jones Villaverde
deaths_March20          = 277*death_inflator;




%% Solve for omegaD that delivers the desired infection_fatality rate
infection_fatality_target = .01; %Target fatality rate of infection -- fraction of people who die from infection 

Pt              = zeros(13,13);
Pt(3,6)         = 1/sigma;
Pt(4,6)         = 1/sigma;
Pt(5,6)         = 1/sigma;
Pt(6,12)        = 1/gamma;
Pt(7,10)        = 1/(sigma+gamma);
Pt(8,11)        = 1/(sigma+gamma);
Pt(9,12)        = 1/(sigma+gamma);
M0              = zeros(13,1);
M0(3)           = psi;
M0(7)           = (1-psi);

maxiter_piD     = 1000;
tol_piD         = 1e-9;
omegaD_min      = 0.0;
omegaD_max      = 1-1/gamma-1e-8;

for iter_omegaD     = (1:maxiter_piD)
    omegaD          = 0.5*(omegaD_min + omegaD_max);
    Pt(6,13)        = omegaD;
    Pdeath          = Pt + diag(1-sum(Pt,2)); 
    ergodic_dist    = (Pdeath')^10000*M0;    

    death_rate_true =  ergodic_dist(13);

    dist_piD        = abs(death_rate_true-infection_fatality_target);
    if dist_piD<tol_piD
        break;
    end
    if (death_rate_true < infection_fatality_target)
        omegaD_min  = omegaD;
    else
        omegaD_max  = omegaD;
    end
    
end

display(['Infection Fatality Rate: ' num2str(death_rate_true) ' : diff_piD : ' num2str(dist_piD) ])
display(['Infection Fatality Rate Percent: ' num2str(100*death_rate_true) ])

fprintf('omegaD = %1.4e\n',omegaD);

%% Set up parameters

model.omegaD      = omegaD;
model.lambdaQ     = rel_lambda*lambda;
model.rhoS        = R0/(psi*sigma*lambda*(rel_rho+(1/sigma)/((1/gamma)+model.omegaD)) + (1-psi)*(sigma+gamma)*lambda*rel_rho) ;
model.rhoA        = rel_rho* model.rhoS; 


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %1. Compute Tstar in Quarantine Only Environment
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Run it with no policy to get tstar
    Tstar_guess             = 365;                        
    
    d_vaccine               = days_Mar20_to_vaccine*hrs+ Tstar_guess*hrs;     % vaccine available date     
    
    policy1.tauV			= 0;
    policy1.tauS			= 0;
    policy1.xiU				= xiU_c;
    policy1.rU_exp          = rU_exp;
    policy1.d_start_exp 	=  Tstar_guess*hrs;       
    policy1.d_start_reopen  =  Tstar_guess*hrs;    
    policy1.d_start_testing =  Tstar_guess*hrs;     

    experiment              = 'exp1';

    [Reported_D_exp1,Notinfected_D_exp1,Unreported_D_exp1,Infected_D_exp1,Recovered_D_exp1,Dead_D_exp1,Infected_T_exp1,Y_D_exp1,Y_T_exp1,M_T_exp1,A_daily,Pt_exp1,number_tests_D_exp1,Rt_D_exp1]  =corona_func_IandPA_to_Ru(policy1,model,experiment);
    
    Tstar               = find(Dead_D_exp1>=deaths_March20,1,'first'); 	
    % Be careful, Tstar is in units of "days", so needs to be multiplied by hrs to get to 'model periods' : Tstar*hrs
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %2. Run full simulation, with policy starting on Tstar
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Rerun with correct Tstar 

    d_vaccine           = days_Mar20_to_vaccine*hrs+ Tstar*hrs;    

    policy1.tauV		    = 0;
    policy1.tauS		    = 0;
    policy1.xiU			    = xiU_c;
    policy1.rU_exp          = rU_exp;
    policy1.d_start_exp     =  Tstar*hrs ; 
    policy1.d_start_reopen  =  Tstar*hrs + days_Mar20_to_reopen*hrs;       
    policy1.d_start_testing =  Tstar*hrs + days_Mar20_to_testing*hrs;     

    experiment          = 'exp1';
    clc;
    [Reported_D_exp1,Notinfected_D_exp1,Unreported_D_exp1,Infected_D_exp1,Recovered_D_exp1,Dead_D_exp1,Infected_T_exp1,Y_D_exp1,Y_T_exp1,M_T_exp1,A_daily,Pt_exp1,number_tests_D_exp1,Rt_D_exp1]  =corona_func_IandPA_to_Ru(policy1,model,experiment);
    Tstar_check         = find(Dead_D_exp1>=deaths_March20,1,'first'); 			% Be careful, Tstar is in units of "days", so needs to be multiplied by hrs to get to 'model periods' : Tstar*hrs
    assert(Tstar==Tstar_check)


days_model    = [1:1:700]';
days_model    = days_model - days_model(find(Dead_D_exp1>=deaths_March20,1,'first'));



target_deaths = Dead_D_exp1(d_conv);


%% Fig4 - Constant Deaths,  computation part

weeks               = 2;    

tau                 = 1/(7*hrs*0.999*weeks);    % constant hourly testing rate
% exp2 only V test  
policy2.tauV                = tau;
policy2.tauS                = 0;
policy2.rU_exp              = rU_exp;  
policy2.xiU                 = xiU_c;
policy2.d_start_exp         = policy1.d_start_exp ;
policy2.d_start_reopen      = policy1.d_start_reopen;
policy2.d_start_testing     = policy1.d_start_testing;     

% rU to be specified in function rU_bisection_IandPA_to_Ru
experiment       	        = 'exp2';
constant                    = 'Deaths' ;
out2_deaths                 = rU_bisection_IandPA_to_Ru(constant,target_deaths,policy2,model,experiment) ;

assert(out2_deaths.bisection.nonconverge==0)
% make sure that it's IandPA to Ru
assert(out2_deaths.exp.Pt(6,11)==1/(gamma) & out2_deaths.exp.Pt(9,11)==1/(sigma+gamma))
assert(out2_deaths.exp.Pt(6,12)==0  & out2_deaths.exp.Pt(9,12)==0)

% exp3 only S test
  
policy3.tauV                = 0;
policy3.tauS                = tau;
policy3.rU_exp              = rU_exp;
policy3.xiU                 = xiU_c;
policy3.d_start_exp         = policy1.d_start_exp ;
policy3.d_start_reopen      = policy1.d_start_reopen;
policy3.d_start_testing     = policy1.d_start_testing;

experiment       	        = 'exp3';
constant                    = 'Deaths' ;
out3_deaths                 = rU_bisection_IandPA_to_Ru(constant,target_deaths,policy3,model,experiment) ;

assert(out3_deaths.bisection.nonconverge==0)
% make sure that it's IandPA to Ru
assert(out3_deaths.exp.Pt(6,11)==1/(gamma) & out3_deaths.exp.Pt(9,11)==1/(sigma+gamma))
assert(out3_deaths.exp.Pt(6,12)==0  & out3_deaths.exp.Pt(9,12)==0)

save IanaPA_recover_to_Ru
%%  Fig4 - Constant deaths; plot weekly monthly paths
clear; clc; load IanaPA_recover_to_Ru;
default_figures

Tplot = 500;
xylinewidth = 1;

close all; 
figure;
set(gcf,'Pos',[-2236,520,2021,564]);    

subplot(1,3,1)
plot(days_model(1:500),Infected_D_exp1(1:500)/Pop*100,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),out2_deaths.exp.Infected_D(1:500)/Pop*100,'-.','color',rgb('Red'))
plot(days_model(1:500),out3_deaths.exp.Infected_D(1:500)/Pop*100,':','color',rgb('Blue'))
title('A. Current symptomatic cases: $I^{+}_{Q}$')
xlabel('Days since March 20, 2020')
ylabel('Fraction of population (\%)') 
xlim([-10 Tplot])
ytickformat('%3.2f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

subplot(1,3,2)
plot(days_model(1:500),Dead_D_exp1(1:500)/Pop*100,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),out2_deaths.exp.Dead_D(1:500)/Pop*100,'-.','color',rgb('Red'))
plot(days_model(1:500),out3_deaths.exp.Dead_D(1:500)/Pop*100,':','color',rgb('Blue'))
title('B. Cumulative deaths')
xlabel('Days since March 20, 2020')
ylabel('Fraction of population (\%)') 
ytickformat('%3.2f')
xlim([-10 Tplot])
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend('Benchmark (no testing)','Virological testing','Serological testing','Location','southeast') ;


subplot(1,3,3)
plot(days_model(1:500),Y_D_exp1(1:500)./Pop,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),out2_deaths.exp.Y_D(1:500)./Pop,'-.','color',rgb('Red'))
plot(days_model(1:500),out3_deaths.exp.Y_D(1:500)./Pop,':','color',rgb('Blue'))
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
title(['C. Relative output: $Y_{t}/Y_{0}$'])
xlabel('Days since March 20, 2020')
ylabel('Relative output')
xlim([-10 Tplot])
ytickformat('%3.2f')
ylim([0.89 1])

saveas(gcf,'.\main_text_figures\fig10_in_paper.png')






