
%% Cumulative
close all
clear 


F1 = figure(1);
set(F1,'Pos',[-1799,544,1486,439]);  
T = readtable('./data/US_cases_deaths.csv');
T(any(ismissing(T), 2), :) = [];

t = datetime(2020,1,22) + caldays(0:(height(T)-1));
T.date      = t';

rows = T.date  >= '24-Feb-2020' &  T.date  <= '27-Aug-2020';
T = T(rows,:);

cases       = T.cases/10^4;
deaths      = T.deaths/10^3;
date        = T.date;

subplot(1,2,1);

font = 20;
set(0,'defaultlinelinewidth',3);

ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';

hold on;

yyaxis right
plot(date,deaths, '--red')
ylabel('Deaths (thousands)','interpreter','latex');
set(gca,'ycolor','red') 
ylim([0, 250]);

yyaxis left
plot(date,cases, 'black')
set(gca,'ycolor','black') 
ylabel('Cases (tens of thousands)','interpreter','latex');
ylim([0, 600]);

xticklabels('manual')

x = [datetime(2020,3,1) datetime(2020,4,1) datetime(2020,5,1) datetime(2020,6,1) datetime(2020,7,1) datetime(2020,8,1) datetime(2020,9,1)];
xticks(x)

xticklabels(datestr(x,'mmm'))


set(gca,'XLim',[date(1) datetime(2020,9,1)]) 
xlabel('Date (1$^{st}$ case 22-Jan)','interpreter','latex');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');

hAx             = gca;                   % get the axes handle
hAx.XTickLabel  = hAx.XTickLabel;        % overwrite the existing tick labels with present 

legend('Cases (left axis)', 'Deaths (right axis)', ...
    'location', 'northwest', 'NumColumns', 1, 'interpreter', 'latex')

title('A. Cumulative','interpreter','latex');
%% rate of testing untested individuals


T2         = readtable('./data/US_testing.csv');
t         = datetime(2020, 1, 22) + caldays(0:(height(T2)-1));
T2.date    = t';

pop             = 340*10^6;
T2.Tested        = T2.positive + T2.negative ;   % total tests 
T2.Pos_and_Neg   = T2.positive + T2.negative;    % positive and negative tests
x               = T2.Tested(2:end) - T2.Tested(1:end-1); % daily tests
T2.NumTests      = [0; x];

rows = T2.date  >= '24-Feb-2020' &  T2.date  <= '27-Aug-2020';
T2               = T2(rows,:);

pos              = T2.positive/10^6;
pos_and_neg      = T2.Pos_and_Neg/10^6;
tested           = (T2.Tested)/10^6;

% the % of untested pop that is tested each day 
share_tested     = (T2.NumTests./(pop -  T2.Tested))*100;

% apply a 7-day MA on share tested
share_tested     = movmean(share_tested,7);

date             = T2.date;

subplot(1,2,2);

font        = 20;
set(0,'defaultlinelinewidth', 3);

ax          = gca;
ax.XGrid    = 'off';
ax.YGrid    = 'on';

hold on;

plot(date,share_tested, 'color', rgb('Black'))
ylabel('Percent per day','interpreter','latex');
set(gca,'ycolor','black') 

xticklabels('manual')
ytickformat('%4.2f')

x = [datetime(2020,3,1) datetime(2020,4,1) datetime(2020,5,1) datetime(2020,6,1) datetime(2020,7,1) datetime(2020,8,1) datetime(2020,9,1)];
xticks(x)

xticklabels(datestr(x,'mmm'))

set(gca,'fontsize', font,'ticklabelinterpreter','latex');
set(gca,'XLim',[date(1) datetime(2020,9,1)]) 

hAx             = gca;                   % get the axes handle
hAx.XTickLabel  = hAx.XTickLabel;        % overwrite the existing tick labels with present 

title('B. Rate of testing untested individuals','interpreter','latex');

saveas(F1,'.\main_text_figures\fig2_in_paper.png')
