clear all
clc
close all

global hrs disimm rel_rho R0 lambda rel_lambda
global Pop ini_inf T_years  T  d_vaccine  rel_prod_Q
global sigma gamma tau psi d_conv V_false_neg S_false_neg 
global rU_start 

%__________________________________________________________________________
%Policy parameters - Fixed
rU_start                = 0.00275;   %*******

reopen_date             = datetime(2020,6,1);
days_Mar20_to_reopen    = days(reopen_date-datetime(2020,3,20));

testing_date            = datetime(2020,6,1);
days_Mar20_to_testing   = days(testing_date-datetime(2020,3,20));

vaccine_date            = datetime(2021,3,20);
days_Mar20_to_vaccine   = days(vaccine_date-datetime(2020,3,20));

xiU_c                   = 0.0026;           % constant quarantine rate for unknown  (hourly)
rU_exp                  = 0 ;               % additional reopening rate

% tests have no false negatives for baseline
V_false_neg             = 0;
S_false_neg             = 0; 
%__________________________________________________________________________
% Quarantine technology
rel_lambda              = 0.16;        		% lambdaQ/lambda
%__________________________________________________________________________
% Time step
hrs                     = 14;           	% Periods per day      
%__________________________________________________________________________
% Parameters
rel_prod_Q              = 0.9;              % Relative productivity of quarantined (A_rel in paper)
disimm                  = 0;                % Dis-Immunity  (0 = complete immunity, 1 = no immunity) % 
rel_rho                 = 1;                % rhoA/rhoS    Relative infectiousness rate 

psi                     = 0.6;              % Fraction who develop symptoms (TA)

sigma                   = hrs*6;            % for transition matrix
gamma                   = hrs*8;            % for transition matrix

R0                      = 2.6;              % Basic reproduction number
lambda                  = 1;                % Meeting rate (=1 is a normalization) 					
Pop                     = 340000000;        % Population
T_years                 = 5;                
T                       = T_years*365*hrs;  
ini_inf                 = 340000;           % initial infection 
%__________________________________________________________________________
% Bisection 
% d_conv is the date when we define 'long term' for target deaths
d_conv       = 1000;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%0.a Load Deaths data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data            = readtable('./data/US_cases_deaths.csv');
start           = find(data.deaths>=1,1,'first');    % in the data when first death appears
data.date(start);                                    % First day when deaths>=1

deaths_data     = data.deaths(start:end);    % pick the ones after first case appears

death_inflator          = 1.33;      % Jones Villaverde
deaths_data             = deaths_data*death_inflator;
deaths_March20          = 277*death_inflator;  % 277 is the number of deaths on Mar 20

days_data               = (1:1:numel(deaths_data))';
days_data               = days_data - days_data(find(deaths_data>=deaths_March20,1,'first'));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%0.b. Load Quarantine rate data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data_Q      = readtable('./data/US_population_under_quarantine.csv');

% normalize the date in data wrt the first day when Q first began
days_data_Q = data_Q.date_numbered - data_Q.date_numbered(1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%0.b. load Jones&Jesus Rt data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data_JFV   = readtable('./data/JFV_US_Rt.csv');
data_JFV(any(ismissing(data_JFV), 2), :) = [];

days_JFV   = days(data_JFV.date - datetime(2020,3,20));

%% Solve for omegaD that delivers the desired infection_fatality rate
infection_fatality_target = .01; %Target fatality rate of infection -- fraction of people who die from infection 

Pt              = zeros(13,13);
Pt(3,6)         = 1/sigma;
Pt(4,6)         = 1/sigma;
Pt(5,6)         = 1/sigma;
Pt(6,12)        = 1/gamma;
Pt(7,10)        = 1/(sigma+gamma);
Pt(8,11)        = 1/(sigma+gamma);
Pt(9,12)        = 1/(sigma+gamma);
M0              = zeros(13,1);
M0(3)           = psi;
M0(7)           = (1-psi);

maxiter_piD     = 1000;
tol_piD         = 1e-9;
omegaD_min      = 0.0;
omegaD_max      = 1-1/gamma-1e-8;

for iter_omegaD     = (1:maxiter_piD)
    omegaD          = 0.5*(omegaD_min + omegaD_max);
    Pt(6,13)        = omegaD;
    Pdeath          = Pt + diag(1-sum(Pt,2)); 
    ergodic_dist    = (Pdeath')^10000*M0;    

    % All infections
    death_rate_true =  ergodic_dist(13);

    dist_piD        = abs(death_rate_true-infection_fatality_target);
    if dist_piD<tol_piD
        break;
    end
    if (death_rate_true < infection_fatality_target)
        omegaD_min  = omegaD;
    else
        omegaD_max  = omegaD;
    end
    
end

display(['Infection Fatality Rate: ' num2str(death_rate_true) ' : diff_piD : ' num2str(dist_piD) ])
display(['Infection Fatality Rate Percent: ' num2str(100*death_rate_true) ])

fprintf('omegaD = %1.4e\n',omegaD);

%% Set up parameters

model.omegaD      = omegaD;
model.lambdaQ     = rel_lambda*lambda;
model.rhoS        = R0/(psi*sigma*lambda*(rel_rho+(1/sigma)/((1/gamma)+model.omegaD)) + (1-psi)*(sigma+gamma)*lambda*rel_rho) ;
model.rhoA        = rel_rho* model.rhoS; 


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %1. Compute Tstar in Quarantine Only Environment
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Run it with no policy to get tstar
    Tstar_guess             = 365;              % Big guess for the first iteration
    
    d_vaccine               = days_Mar20_to_vaccine*hrs+ Tstar_guess*hrs;     % vaccine available date     
    
    % no test, no release, only xi_U nonzero

    policy1.tauV			= 0;
    policy1.tauS			= 0;
    policy1.xiU				= xiU_c;
    policy1.rU_exp          = rU_exp;
    policy1.d_start_exp 	=  Tstar_guess*hrs;       
    policy1.d_start_reopen  =  Tstar_guess*hrs;     
    policy1.d_start_testing =  Tstar_guess*hrs;     
    
    
    experiment              = 'exp1';  

    [Reported_D_exp1,Notinfected_D_exp1,Unreported_D_exp1,Infected_D_exp1,Recovered_D_exp1,Dead_D_exp1,Infected_T_exp1,Y_D_exp1,Y_T_exp1,M_T_exp1,A_daily,Pt_exp1,number_tests_D_exp1,Rt_D_exp1,RtC_exp1,rU_D_exp1]  =corona_func(policy1,model,experiment);

    Tstar               = find(Dead_D_exp1>=deaths_March20,1,'first'); 	
    % Tstar is in units of "days", so needs to be multiplied by hrs to get to 'model periods' : Tstar*hrs
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %2. Run full simulation, with policy starting on Tstar
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Rerun with correct Tstar 

    d_vaccine           = days_Mar20_to_vaccine*hrs+ Tstar*hrs;    

    policy1.tauV		= 0;
    policy1.tauS		= 0;
    policy1.xiU			= xiU_c;
    policy1.rU_exp      = rU_exp;
    policy1.d_start_exp =  Tstar*hrs ; 
    policy1.d_start_reopen  =  Tstar*hrs + days_Mar20_to_reopen*hrs;       
    policy1.d_start_testing =  Tstar*hrs + days_Mar20_to_testing*hrs;     
    
    experiment          = 'exp1_CoriR';  % only need CoriR here
    clc;
    [Reported_D_exp1,Notinfected_D_exp1,Unreported_D_exp1,Infected_D_exp1,Recovered_D_exp1,Dead_D_exp1,Infected_T_exp1,Y_D_exp1,Y_T_exp1,M_T_exp1,A_daily,Pt_exp1,number_tests_D_exp1,Rt_D_exp1,RtC_exp1,rU_D_exp1]  =corona_func(policy1,model,experiment);
    Tstar_check         = find(Dead_D_exp1>=deaths_March20,1,'first'); 			
    assert(Tstar==Tstar_check)


days_model    = [1:1:700]';
days_model    = days_model - days_model(find(Dead_D_exp1>=deaths_March20,1,'first'));

% record daily population under quarantine 
MQ_D          = sum(M_T_exp1([2,4,5,6,8,9,11]',A_daily));

% record output loss
sum_Y1        = sum(Y_D_exp1((policy1.d_start_exp/hrs):1:(policy1.d_start_exp/hrs+365))-Y_T_exp1(1)) ;  % used Y_T(1) instead of Y_D(1) since Y_T(1) is the *very* initial output

target_deaths = Dead_D_exp1(d_conv);

save main_figures_first_part

%% Population under quarantine figure
close all; clear; load  main_figures_first_part
Tplot  = 500;
xylinewidth = 1;
default_figures

close all;
F1 = figure(1);
set(F1,'Pos',[-1779,416,1466,566]);  % set a position that suits your screen

non_essential = data_Q.frac_under_Q*(1-0.45);

subplot(1,2,1)
p1 = plot(days_data_Q,data_Q.frac_under_Q,'-.','color',rgb('Grey'));
grid on; hold on;
p3 = plot(days_model(1:Tplot),MQ_D(1:Tplot),'-','color',rgb('Black'));
p2 = plot(days_data_Q,non_essential,':','color',rgb('Green'));

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% fill the lines until max
plot(days_data_Q(end-3:end),data_Q.frac_under_Q(end-3:end),'-.','color',rgb('Grey'))
plot(days_data_Q(end-5:end),non_essential(end-5:end),':','color',rgb('Green'))

% plot the yline, make them extend to the right
max_Q       = max(data_Q.frac_under_Q) ;
max_basic   = max(non_essential) ;
idx         = find(data_Q.frac_under_Q==max_Q,1,'first') ;
days_yline  = [days_data_Q(idx):1:Tplot];
plot(days_yline,max_Q*ones(1,length(days_yline)),'--','color',rgb('Grey'),'linewidth',1)
plot(days_yline,max_basic*ones(1,length(days_yline)),'--','color',rgb('Green'),'linewidth',1)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend([p1 p2 p3],'Data: quarantine','Data: non-essential quarantine [(1-0.45)*quarantine]','Model: population in quarantine','Location','southeast','fontsize',12) ;

title('Population in quarantine' )
xlabel('Days since March 20, 2020');
ytickformat('%3.2f')
xlim([days_model(1) 100])


subplot(1,2,2)
plot(days_data_Q,data_Q.frac_under_Q,'-.','color',rgb('Grey'));
grid on; hold on;
plot(days_model(1:Tplot),MQ_D(1:Tplot),'-','color',rgb('Black')) ;
plot(days_data_Q,data_Q.frac_under_Q*(1-0.45),':','color',rgb('Green'));
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% fill the lines until max
plot(days_data_Q(end-1:end),data_Q.frac_under_Q(end-1:end),'-.','color',rgb('Grey'))
plot(days_data_Q(end-5:end),data_Q.frac_under_Q(end-5:end)*(1-0.45),':','color',rgb('Green'))
% plot the yline, make them extend to the right
plot(days_yline,max_Q*ones(1,length(days_yline)),'--','color',rgb('Grey'),'linewidth',1)
plot(days_yline,max_basic*ones(1,length(days_yline)),'--','color',rgb('Green'),'linewidth',1)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

title('Population in quarantine' )
xlabel('Days since March 20, 2020');
ytickformat('%3.2f')
xlim([days_model(1) Tplot])

saveas(gcf,'.\appendix_figures\pop_in_Q.png')

%% Figures 1 - Model Fit 
close all; clear; load  main_figures_first_part
Tplot  = 500;
xylinewidth = 1;
default_figures

F1 = figure(1);
set(F1,'Pos',[-2104,214,1737,1011]);    
subplot(2,3,1)
plot(days_model(1:500),Infected_D_exp1(1:500)/Pop*100,'-.','color',rgb('Black'))
grid on; hold on;
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
xlim([-10 Tplot])
xlabel('Days since March 20, 2020');
ylabel('Fraction of population (\%)')
title('A. Current symptomatic cases: $I_{Q}^{+}$')
l = legend('Model','Location','northeast','fontsize',13) ;

txt_reopen = ['$\leftarrow$ Reopen ' datestr(reopen_date,'mmm dd,yyyy')];
txt_vaccine = ['$\;$ Vaccine $\rightarrow$  ' datestr(vaccine_date,'mmm dd,yyyy')];

dim   = [0.16527,0.8544,0.0727,0.0589];
annotation('textbox',dim, 'string', txt_reopen ,'linewidth',.5,'interpreter','latex','fontsize',15,'edgecolor','none')
dim   = [0.2200,0.7969,0.07326,0.05232];
annotation('textbox',dim, 'string', txt_vaccine ,'linewidth',.5,'interpreter','latex','fontsize',15,'edgecolor','none')


deaths_daily_data  = [deaths_data(1) ; deaths_data(2:end)-deaths_data(1:end-1)];
deaths_daily_data  = movmean(deaths_daily_data,5) ;
deaths_daily_model = [Dead_D_exp1(1) ; Dead_D_exp1(2:end)-Dead_D_exp1(1:end-1)];

subplot(2,3,2)
p2_2 = plot(days_model(1:Tplot),Dead_D_exp1(1:Tplot)/1000,'-.','color',rgb('Black'));
grid on; hold on;
p2_1 = plot(days_data,deaths_data/1000,'-','color',rgb('Grey'),'linewidth',5) ;

%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
xlim([days_data(1) Tplot])
xlabel('Days since March 20, 2020');
ylabel('Number of deaths (1000''s)')
title('B. Cumulative deaths' )
l = legend([p2_1 p2_2],'Data','Model','Location','southeast','fontsize',13) ;


subplot(2,3,3)
p3_2 = plot(days_model(1:Tplot),deaths_daily_model(1:Tplot),'-.','color',rgb('Black'));
grid on; hold on;
p3_1 = plot(days_data ,deaths_daily_data,'-','color',rgb('Grey'),'linewidth',5) ;
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend([p3_1 p3_2],'Data','Model','Location','northeast','fontsize',13) ;
xlabel('Days since March 20, 2020');
ylabel('Number of deaths')
title('C. Daily deaths' )
ytickformat('%3.0f')
xlim([days_data(1) Tplot])


subplot(2,3,4)
Yplot1 = Y_D_exp1/Y_T_exp1(1);
plot(days_model(1:Tplot),Yplot1(1:Tplot),'-.','color',rgb('Black'));
hold on;grid on; 
xlabel('Days since March 20, 2020');
ylabel('Relative output')
title('D. Relative output: $Y_{t}/Y_{0}$' )
xlim([days_model(1) Tplot])
xlabel('Days since March 20, 2020');
ytickformat('%3.2f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend('Model','Location','southeast','fontsize',13) ;

subplot(2,3,5)
plot(days_model(1:Tplot),rU_D_exp1(1:Tplot)*hrs,'-.','color',rgb('Black'));
hold on; grid on;
plot(days_model(1:Tplot),policy1.xiU*hrs*ones(1,Tplot),'-','color',rgb('Green'))
% yline(policy1.xiU*hrs,'-','color',rgb('Green'),'linewidth',4)
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend('$r^{u}_{t}$','$\xi^{u}$','Location','southeast','fontsize',13) ;
xlabel('Days since March 20, 2020');
ylabel('Daily rate')
title('E. Quarantine exit $r_t^u$ \& entry $\xi^u$ rate (daily)' )
xlim([days_model(1) Tplot])
xlabel('Days since March 20, 2020');
ytickformat('%3.2f')

subplot(2,3,6)
plot(days_model(1:Tplot),Rt_D_exp1(1:Tplot),'-.','color',rgb('Black'))
hold on;grid on;
plot(days_model(1:Tplot),RtC_exp1(1:Tplot),'--','color',rgb('Red'))
plot(days_JFV,data_JFV.Rt,'-','color',rgb('Blue'))
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
%yline(1,'--','linewidth',xylinewidth)
l = legend('Wallinga-Teunis','Cori','Jones Fernandez-Villaverde','Location','northeast','fontsize',13) ;
xlim([days_model(1) Tplot])
xlabel('Days since March 20, 2020');
ylabel('$R_{t}$')
title('F. Reproduction numbers' );ytickformat('%3.2f')


saveas(gcf,'.\main_text_figures\fig4_in_paper.png')

%% Fig2 -- Non-Constant Deaths: fix xiU, zero rU; Computation part
clear; load main_figures_first_part

days_for_output  = days(vaccine_date - reopen_date);  % reopen date to vaccine date

sum_Y1        = sum(Y_D_exp1((policy1.d_start_reopen/hrs):1:(policy1.d_start_reopen/hrs+days_for_output))-Y_T_exp1(1)) ;  % used Y_T(1) instead of Y_D(1) since Y_T(1) is the *very* initial output
denom         = -sum_Y1 ;
weeks_grid3   = [1:1:12] ;

output_nobench_grid2 = zeros(1,length(weeks_grid3));
output_nobench_grid3 = zeros(1,length(weeks_grid3));

deaths_nobench_grid2 = zeros(1,length(weeks_grid3));
deaths_nobench_grid3 = zeros(1,length(weeks_grid3));

for xx = 1:length(weeks_grid3)
    %______________________________________________________________________
    weeks  = weeks_grid3(xx) ; 
    tau    = 1/(7*hrs*0.999*weeks);    % constant hourly testing rate
    %______________________________________________________________________
    % exp2 - Virological test
    policy2.tauV                = tau;
    policy2.tauS                = 0;
    policy2.rU_exp              = rU_exp;
    policy2.xiU                 = xiU_c;
    policy2.d_start_exp         = policy1.d_start_exp ;
    policy2.d_start_reopen      = policy1.d_start_reopen;
    policy2.d_start_testing     = policy1.d_start_testing;     
    
    experiment                  = 'exp2';
    
    [exp2.Reported_D,exp2.Notinfected_D,exp2.Unreported_D,exp2.Infected_D,exp2.Recovered_D,exp2.Dead_D,exp2.Infected_T,exp2.Y_D,exp2.Y_T,exp2.M_T,exp2.A_daily,exp2.Pt,exp2.number_tests_D,exp2.Rt_D,exp2.RtC,exp2.rU_D]  =corona_func(policy2,model,experiment);
     
    numerator2                  = sum(exp2.Y_T(1) - exp2.Y_D(policy2.d_start_reopen/hrs:1:(policy2.d_start_reopen/hrs+days_for_output)) );
    output_nobench_grid2(xx)    = numerator2/denom;    
    deaths_nobench_grid2(xx)    = exp2.Dead_D(d_conv)/Dead_D_exp1(d_conv);
   
    eval(['all_exp2.nobench.weeks_' num2str(weeks) '= exp2 ;' ])
    %______________________________________________________________________  
    % exp3 - Serological test
    policy3.tauV                = 0;
    policy3.tauS                = tau;
    policy3.rU_exp              = rU_exp;
    policy3.xiU                 = xiU_c;
    policy3.d_start_exp         = policy1.d_start_exp ;
    policy3.d_start_reopen      = policy1.d_start_reopen;
    policy3.d_start_testing     = policy1.d_start_testing;   

    experiment                  = 'exp3';
    
    [exp3.Reported_D,exp3.Notinfected_D,exp3.Unreported_D,exp3.Infected_D,exp3.Recovered_D,exp3.Dead_D,exp3.Infected_T,exp3.Y_D,exp3.Y_T,exp3.M_T,exp3.A_daily,exp3.Pt,exp3.number_tests_D,exp3.Rt_D,exp3.RtC,exp3.rU_D]  =corona_func(policy3,model,experiment);
    numerator3                  = sum(exp3.Y_T(1) - exp3.Y_D(policy3.d_start_reopen/hrs:1:(policy3.d_start_reopen/hrs+days_for_output)) );
    output_nobench_grid3(xx)    = numerator3/denom;    
    deaths_nobench_grid3(xx)    = exp3.Dead_D(d_conv)/Dead_D_exp1(d_conv);
    
    eval(['all_exp3.nobench.weeks_' num2str(weeks) '= exp3 ;' ])
    %______________________________________________________________________
end

save main_figures_second_part

%% Fig2 - Non-constant deaths, plot bi-weekly paths
clear; load main_figures_second_part
default_figures

close all; 
F1 = figure(1);
set(F1,'Pos',[-2104,214,1737,1011]);    
Tplot = 500;
xylinewidth = 1;


subplot(2,3,1)
plot(days_model(1:500),Infected_D_exp1(1:500)/Pop*100,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.nobench.weeks_2.Infected_D(1:500)/Pop*100,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.nobench.weeks_2.Infected_D(1:500)/Pop*100,':','color',rgb('Blue'))
title('A. Current symptomatic cases: $I^{+}_{Q}$')
xlabel('Days since March 20, 2020')
ylabel('Fraction of population (\%)') 
ytickformat('%3.2f')
xlim([-10 Tplot])
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend('Benchmark (no testing)','Virological testing','Serological testing','Location','northeast') ;

subplot(2,3,2)
plot(days_model(1:500),Dead_D_exp1(1:500)/Pop*100,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.nobench.weeks_2.Dead_D(1:500)/Pop*100,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.nobench.weeks_2.Dead_D(1:500)/Pop*100,':','color',rgb('Blue'))
title('B. Cumulative deaths')
xlabel('Days since March 20, 2020')
ylabel('Fraction of population (\%)') 
xlim([-10 Tplot])
ytickformat('%3.2f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

deaths_daily_model = [Dead_D_exp1(1) ; Dead_D_exp1(2:end)-Dead_D_exp1(1:end-1)];
deaths_daily_mode2 = [all_exp2.nobench.weeks_2.Dead_D(1) ; all_exp2.nobench.weeks_2.Dead_D(2:end)-all_exp2.nobench.weeks_2.Dead_D(1:end-1)];
deaths_daily_mode3 = [all_exp3.nobench.weeks_2.Dead_D(1) ; all_exp3.nobench.weeks_2.Dead_D(2:end)-all_exp3.nobench.weeks_2.Dead_D(1:end-1)];

subplot(2,3,3)
plot(days_model(1:500),deaths_daily_model(1:500),'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),deaths_daily_mode2(1:500),'-.','color',rgb('Red'))
plot(days_model(1:500),deaths_daily_mode3(1:500),':','color',rgb('Blue'))
title(['C. Daily deaths'])
xlabel('Days since March 20, 2020')
ylabel('Number of deaths')
xlim([-10 Tplot])
ytickformat('%5.0f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

subplot(2,3,4)
plot(days_model(1:500),Y_D_exp1(1:500)./Pop,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.nobench.weeks_2.Y_D(1:500)./Pop,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.nobench.weeks_2.Y_D(1:500)./Pop,':','color',rgb('Blue'))
title(['D. Relative output: $Y_{t}/Y_{0}$'])
xlabel('Days since March 20, 2020')
ylabel('Relative output')
xlim([-10 Tplot])
ytickformat('%3.2f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

subplot(2,3,5)
plot(days_model(1:500),rU_D_exp1(1:500)*hrs,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.nobench.weeks_2.rU_D(1:500)*hrs,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.nobench.weeks_2.rU_D(1:500)*hrs,':','color',rgb('Blue'))
plot(days_model(1:Tplot),policy1.xiU*hrs*ones(1,Tplot),'-','color',rgb('Green'))
% yline(policy1.xiU*hrs,'-','color',rgb('Green'),'linewidth',4)
title('E. Quarantine exit $r_t^u$ \& entry $\xi^u$ rate (daily)')
xlabel('Days since March 20, 2020')
ylabel('Daily release rate')
xlim([-10 Tplot])
ytickformat('%3.2f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
l = legend('Benchmark $r^{u}_{t}$','Virological testing $r^{u}_{t}$','Serological testing $r^{u}_{t}$','Common $\xi^{u}$','Location','southeast','fontsize',11) ;

subplot(2,3,6)
plot(days_model(1:500),Rt_D_exp1(1:500),'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.nobench.weeks_2.Rt_D(1:500),'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.nobench.weeks_2.Rt_D(1:500),':','color',rgb('Blue'))
title(['F. Walliga-Teunis $R_{t}$'])
xlabel('Days since March 20, 2020')
ylabel('$R_{t}$')
xlim([-10 Tplot])
ytickformat('%3.2f')
%yline(1,'--','linewidth',xylinewidth)
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

saveas(F1,'.\main_text_figures\fig5_in_paper.png')


%% Fig3 - Non-constant deaths, plot Output & Deaths, varying testing

clear; load main_figures_second_part;
default_figures

close all;
F1 = figure(3);
set(F1,'Pos',[-1962,523,1342,546]);   
font = 18;

% output loss relative to only Q
subplot(1,2,1)
plot(weeks_grid3,1-output_nobench_grid2,'--','color',rgb('Red'))
hold on; grid on;
plot(weeks_grid3,1-output_nobench_grid3,'-.','color',rgb('Blue'))
%yline(0,'linewidth',1);
xlabel('Average weeks between tests');
ylabel('Output loss saved relative to benchmark')
set(gca, 'XTick', weeks_grid3)
set(gca, 'TickLabelInterpreter', 'latex', 'XTickLabel', {'1', '2', '3', '4', '5', '6','7','8','9','10','11','12'})
title('A. Economic outcomes - Output loss saved')
set(gca,'fontsize',font);
ytickformat('%4.2f');
xlim([1,12])
l = legend('Virological testing','Serological testing','Location','northeast') ;

% deaths relative to only Q
% close all 
subplot(1,2,2)
plot(weeks_grid3,1-deaths_nobench_grid2,'--','color',rgb('Red'))
hold on; grid on;
plot(weeks_grid3,1-deaths_nobench_grid3,'-.','color',rgb('Blue'))
xlabel('Average weeks between tests');
ylabel('Fraction of benchmark deaths avoided')
set(gca, 'XTick', weeks_grid3)
set(gca, 'TickLabelInterpreter', 'latex', 'XTickLabel', {'1', '2', '3', '4', '5', '6','7','8','9','10','11','12'})
title('B. Health outcomes - Lives saved')
set(gca,'fontsize',font);
ytickformat('%4.2f');
xlim([1,12])

saveas(F1,'.\main_text_figures\fig6_in_paper.png')


%% Fig4 - Constant Deaths,  computation part
clear; clc; load main_figures_second_part
weeks_grid2     = [1.15 1.5 2:1:12];    

days_for_output = days(vaccine_date - reopen_date);  % Jun1 to date_end

sum_Y1          = sum(Y_D_exp1((policy1.d_start_reopen/hrs):1:(policy1.d_start_reopen/hrs+days_for_output))-Y_T_exp1(1)) ;  % used Y_T(1) instead of Y_D(1) since Y_T(1) is the *very* initial output

output2_cd_grid = zeros(1,length(weeks_grid2));   % record relative output loss when deaths constant
output3_cd_grid = zeros(1,length(weeks_grid2));
output4_cd_grid = zeros(1,length(weeks_grid2));

rU2_cd_grid = zeros(1,length(weeks_grid2));        % record rU when deaths constant
rU3_cd_grid = zeros(1,length(weeks_grid2)); 
rU4_cd_grid = zeros(1,length(weeks_grid2)); 



for xx = 1:length(weeks_grid2)
% xx = 1 ;
weeks               = weeks_grid2(xx);    
tau                 = 1/(7*hrs*0.999*weeks);    % constant hourly testing rate


    %______________________________________________________________________
    % exp2 - Virological test    
    policy2.tauV                = tau;
    policy2.tauS                = 0;
    policy2.xiU                 = xiU_c;
    policy2.d_start_exp         = policy1.d_start_exp;
    policy2.d_start_reopen      = policy1.d_start_reopen;
    policy2.d_start_testing     = policy1.d_start_testing;  

    % rU to be specified in function rU_bisection 
    experiment       	= 'exp2';
    constant            = 'Deaths' ;
    out2_deaths         = rU_bisection(constant,target_deaths,policy2,model,experiment) ;
    numerator2          = sum(out2_deaths.exp.Y_T(1) - out2_deaths.exp.Y_D(policy2.d_start_reopen/hrs:1:(policy2.d_start_reopen/hrs+days_for_output)) );
    output2_cd_grid(xx) = numerator2/(-sum_Y1) ;
    rU2_cd_grid(xx)     = out2_deaths.rU ;

    eval(['all_exp2.cons_deaths.weeks_position'  num2str(xx)  ' = out2_deaths ;'])
    assert(out2_deaths.bisection.nonconverge==0)
    % record bi-weekly rU for fig 8
    if weeks == 2
       rU_record_weeks_2  = load('baseline_exp2','rU_D','rU_exp_D','rU_endo_D') ; 
    end
    
    if xx == 1
       rU_record_weeks_1  = load('baseline_exp2','rU_D','rU_exp_D','rU_endo_D') ; 
    end
    
    %______________________________________________________________________
    % exp3 - Serological test
    policy3.tauV              = 0;
    policy3.tauS              = tau;
    policy3.xiU               = xiU_c;
    policy3.d_start_exp       = policy1.d_start_exp;
    policy3.d_start_reopen    = policy1.d_start_reopen;
    policy3.d_start_testing   = policy1.d_start_testing;  

    experiment         	= 'exp3';
    constant            = 'Deaths' ;
    out3_deaths         = rU_bisection(constant,target_deaths,policy3,model,experiment) ;
    numerator3          = sum(out3_deaths.exp.Y_T(1) - out3_deaths.exp.Y_D(policy3.d_start_reopen/hrs:1:(policy3.d_start_reopen/hrs+days_for_output)));
    output3_cd_grid(xx) = numerator3/(-sum_Y1) ;
    rU3_cd_grid(xx)     = out3_deaths.rU ;
    eval(['all_exp3.cons_deaths.weeks_position'  num2str(xx) ' = out3_deaths ;'])
    assert(out3_deaths.bisection.nonconverge==0)


end



save main_figures_third_part

%%  Fig4 - Constant deaths; plot bi-weekly paths
clear; clc; load main_figures_third_part
default_figures

Tplot       = 500;
xylinewidth = 1;
close all; 
figure;
set(gcf,'Pos',[-1711,196,1302,964]);    

subplot(2,2,1) 
p2 = plot(days_model(1:500),   rU_record_weeks_2.rU_D(1:500)*hrs,'-.','color',rgb('Red'));
grid on; hold on;

plot(days_model(1:500),   rU_record_weeks_2.rU_exp_D(1:500)*hrs,   '-.','color',rgb('Red'));
p4 = plot(days_model(1:30:500),rU_record_weeks_2.rU_exp_D(1:30:500)*hrs,'o','color',rgb('Red'),'markersize',11);
plot(days_model(1:500),   rU_record_weeks_2.rU_endo_D(1:500)*hrs,   '-.','color',rgb('Red'));
p6 = plot(days_model(1:30:500),rU_record_weeks_2.rU_endo_D(1:30:500)*hrs,'s','color',rgb('Red'),'markersize',11);

%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
title('A. Reopening rates')
xlabel('Days since March 20, 2020')
ylabel('Daily reopening rate') 
xlim([-10 Tplot])
ylim([0 0.12])
ytickformat('%3.2f')
l = legend([p2 p4 p6],'$r^{u}_{t}$','$r^{u,Pol}$','$r^{u,Endog}_{t}$','Location','northwest') ;



subplot(2,2,2)
plot(days_model(1:500),Infected_D_exp1(1:500)/Pop*100,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.cons_deaths.weeks_position3.exp.Infected_D(1:500)/Pop*100,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.cons_deaths.weeks_position3.exp.Infected_D(1:500)/Pop*100,':','color',rgb('Blue'))
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)
title('B. Current symptomatic cases: $I^{+}_{Q}$')
xlabel('Days since March 20, 2020')
ylabel('Fraction of population (\%)') 
xlim([-10 Tplot])
ytickformat('%3.2f')
l = legend('Benchmark (no testing)','Virological testing','Serological testing','Location','northeast') ;

subplot(2,2,3)
plot(days_model(1:500),Y_D_exp1(1:500)./Pop,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.cons_deaths.weeks_position3.exp.Y_D(1:500)./Pop,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.cons_deaths.weeks_position3.exp.Y_D(1:500)./Pop,':','color',rgb('Blue'))
title(['C. Relative output: $Y_{t}/Y_{0}$'])
xlabel('Days since March 20, 2020')
ylabel('Relative output')
xlim([-10 Tplot])
ytickformat('%3.2f')
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

subplot(2,2,4)
plot(days_model(1:500),Dead_D_exp1(1:500)/Pop*100,'--','color',rgb('Black'))
grid on; hold on;
plot(days_model(1:500),all_exp2.cons_deaths.weeks_position3.exp.Dead_D(1:500)/Pop*100,'-.','color',rgb('Red'))
plot(days_model(1:500),all_exp3.cons_deaths.weeks_position3.exp.Dead_D(1:500)/Pop*100,':','color',rgb('Blue'))
title('D. Cumulative deaths')
xlabel('Days since March 20, 2020')
ylabel('Fraction of population (\%)') 
ytickformat('%3.2f')
xlim([-10 Tplot])
%xline(days_Mar20_to_reopen,'linewidth',xylinewidth)
%xline(days_Mar20_to_vaccine,'linewidth',xylinewidth)

saveas(gcf,'.\main_text_figures\fig8_in_paper.png')


%% Fig5 - Constant deaths, plot Output & Deaths, varying testing

clear; clc; load main_figures_third_part
default_figures

close all;
F1 = figure(3);
set(F1,'Pos',[-1962,523,1342,546]);    
font = 18;

% output loss relative to only Q
subplot(1,2,1)
plot(weeks_grid2,1-output2_cd_grid,'--','color',rgb('Red'))
hold on; grid on;
plot(weeks_grid2,1-output3_cd_grid,'-.','color',rgb('Blue'))
xlabel('Average weeks between tests');
ylabel('Output loss saved relative to benchmark')
set(gca, 'XTick', weeks_grid2)
set(gca, 'TickLabelInterpreter', 'latex', 'XTickLabel', {'1', '', '2', '3', '4', '5', '6','7','8','9','10','11','12'})
title('A. Economic outcomes - Output loss saved')
set(gca,'fontsize',font);
ytickformat('%4.2f');
xlim([1,12])
l = legend('Virological testing','Serological testing','Location','northeast') ;

% deaths relative to only Q
subplot(1,2,2)
plot(weeks_grid2,rU2_cd_grid*hrs,'--','color',rgb('Red'))
hold on; grid on;
plot(weeks_grid2,rU3_cd_grid*hrs,'-.','color',rgb('Blue'))
xlabel('Average weeks between tests');
ylabel('Daily reopening rate')
set(gca, 'XTick', weeks_grid2)
set(gca, 'TickLabelInterpreter', 'latex', 'XTickLabel', {'1', '', '2', '3', '4', '5', '6','7','8','9','10','11','12'})
title('B. Daily additional reopening rate: $r^{u,Pol}$')
set(gca,'fontsize',font);
ytickformat('%4.2f');
xlim([1,12])
ylim([0 1])
arrow = ['$\nwarrow\; r^{u,Pol} =' num2str(rU2_cd_grid(1)*hrs,'%3.2f') '$ for testing at weekly frequency'];
dim   = [0.588734658055969,0.814325966625966,0.330208875641663,0.0653];
annotation('textbox',dim, 'string', arrow ,'linewidth',.5,'interpreter','latex','fontsize',15,'edgecolor','none')

saveas(F1,'.\main_text_figures\fig7_in_paper.png')


